==> openshift-model-operator-5.12.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeSchedulerBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class KubeSchedulerBuilder extends io.fabric8.openshift.api.model.operator.v1.KubeSchedulerFluentImpl<io.fabric8.openshift.api.model.operator.v1.KubeSchedulerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.KubeScheduler,io.fabric8.openshift.api.model.operator.v1.KubeSchedulerBuilder>{
  public KubeSchedulerBuilder() {
    this(false);
  }
  public KubeSchedulerBuilder(java.lang.Boolean validationEnabled) {
    this(new KubeScheduler(), validationEnabled);
  }
  public KubeSchedulerBuilder(io.fabric8.openshift.api.model.operator.v1.KubeSchedulerFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeSchedulerBuilder(io.fabric8.openshift.api.model.operator.v1.KubeSchedulerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new KubeScheduler(), validationEnabled);
  }
  public KubeSchedulerBuilder(io.fabric8.openshift.api.model.operator.v1.KubeSchedulerFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeScheduler instance) {
    this(fluent, instance, false);
  }
  public KubeSchedulerBuilder(io.fabric8.openshift.api.model.operator.v1.KubeSchedulerFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.KubeScheduler instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeSchedulerBuilder(io.fabric8.openshift.api.model.operator.v1.KubeScheduler instance) {
    this(instance,false);
  }
  public KubeSchedulerBuilder(io.fabric8.openshift.api.model.operator.v1.KubeScheduler instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.KubeSchedulerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.KubeScheduler build() {
    KubeScheduler buildable = new KubeScheduler(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KubeSchedulerBuilder that = (KubeSchedulerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/KubeSchedulerBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KubeSchedulerBuilder extends KubeSchedulerFluentImpl<KubeSchedulerBuilder> implements VisitableBuilder<KubeScheduler,KubeSchedulerBuilder>{
  public KubeSchedulerBuilder() {
    this(false);
  }
  public KubeSchedulerBuilder(Boolean validationEnabled) {
    this(new KubeScheduler(), validationEnabled);
  }
  public KubeSchedulerBuilder(KubeSchedulerFluent<?> fluent) {
    this(fluent, false);
  }
  public KubeSchedulerBuilder(KubeSchedulerFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KubeScheduler(), validationEnabled);
  }
  public KubeSchedulerBuilder(KubeSchedulerFluent<?> fluent,KubeScheduler instance) {
    this(fluent, instance, false);
  }
  public KubeSchedulerBuilder(KubeSchedulerFluent<?> fluent,KubeScheduler instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public KubeSchedulerBuilder(KubeScheduler instance) {
    this(instance,false);
  }
  public KubeSchedulerBuilder(KubeScheduler instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  KubeSchedulerFluent<?> fluent;
  Boolean validationEnabled;
  public KubeScheduler build() {
    KubeScheduler buildable = new KubeScheduler(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
